import 'package:example/provider.dart';
import 'package:example/stores/counter.dart';
import 'package:flutter/material.dart';
import 'package:nexstate_flutter/nexstate_flutter.dart';

void main() => runApp(const App());

class App extends StatelessWidget {
  const App({final Key? key}) : super(key: key);

  @override
  Widget build(final BuildContext context) {
    return Provider(
      child: MaterialApp(
        title: 'Nexstate Flutter Example',
        theme: ThemeData(primarySwatch: Colors.blue),
        home: const HomeScreen(title: 'Nexstate Flutter Example Home Screen'),
      ),
    );
  }
}

class HomeScreen extends StatelessWidget {
  final String title;

  const HomeScreen({required this.title, final Key? key}) : super(key: key);

  @override
  Widget build(final BuildContext context) {
    return Consumer<Counter>(
      store: Provider.of(context).counter,
      builder: (final context, final store) {
        return Scaffold(
          appBar: AppBar(title: Text(title)),
          body: Center(
            child: Column(
              mainAxisAlignment: MainAxisAlignment.center,
              children: <Widget>[
                const Text('You have pushed the button this many times:'),
                Text(
                  store.value.toString(),
                  style: Theme.of(context).textTheme.headline4,
                ),
              ],
            ),
          ),
          floatingActionButton: FloatingActionButton(
            onPressed: store.increment,
            tooltip: 'Increment',
            child: const Icon(Icons.add),
          ),
        );
      },
    );
  }
}
