import 'package:flutter/material.dart';
import 'package:nexstate/nexstate.dart';

/// Wrap this widget around parts that need to be rebuilt every time a specific
/// nexstate store is updated with `setState` method.
class Consumer<T extends Store> extends StatefulWidget {
  final T store;
  final Widget Function(BuildContext context, T store) builder;

  const Consumer({
    required this.store,
    required this.builder,
    final Key? key,
  }) : super(key: key);

  @override
  State<StatefulWidget> createState() => _ConsumerState<T>();
}

class _ConsumerState<T extends Store> extends State<Consumer<T>> {
  late final Subscription subscription;

  @override
  void initState() {
    super.initState();
    subscription = widget.store.subscribe(() => setState(() {}));
  }

  @override
  void dispose() {
    subscription.cancel();
    super.dispose();
  }

  @override
  Widget build(final BuildContext context) {
    return widget.builder(context, widget.store);
  }
}
