import 'package:flutter/material.dart';

/// Extend this class to create providers. You can assign nexstate stores as
/// fields to providers. This way, stores can be used deep in your widget tree.
abstract class ProviderScaffold extends InheritedWidget {
  const ProviderScaffold({
    required Widget child,
    final Key? key,
  }) : super(key: key, child: child);

  static T of<T extends ProviderScaffold>(final BuildContext context) {
    final result = context.dependOnInheritedWidgetOfExactType<T>();
    assert(result != null, 'No $T found in context');
    return result!;
  }

  @override
  bool updateShouldNotify(covariant final InheritedWidget oldWidget) =>
      oldWidget != this;
}
